summaryrefslogtreecommitdiffstats
path: root/contrib/llvm/include/llvm/CodeGen/ParallelCG.h
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/llvm/include/llvm/CodeGen/ParallelCG.h')
-rw-r--r--contrib/llvm/include/llvm/CodeGen/ParallelCG.h25
1 files changed, 15 insertions, 10 deletions
diff --git a/contrib/llvm/include/llvm/CodeGen/ParallelCG.h b/contrib/llvm/include/llvm/CodeGen/ParallelCG.h
index fa7002f..14ef0ec 100644
--- a/contrib/llvm/include/llvm/CodeGen/ParallelCG.h
+++ b/contrib/llvm/include/llvm/CodeGen/ParallelCG.h
@@ -14,29 +14,34 @@
#ifndef LLVM_CODEGEN_PARALLELCG_H
#define LLVM_CODEGEN_PARALLELCG_H
-#include "llvm/ADT/ArrayRef.h"
#include "llvm/Support/CodeGen.h"
#include "llvm/Target/TargetMachine.h"
+#include <functional>
+
namespace llvm {
+template <typename T> class ArrayRef;
class Module;
class TargetOptions;
class raw_pwrite_stream;
/// Split M into OSs.size() partitions, and generate code for each. Writes
/// OSs.size() output files to the output streams in OSs. The resulting output
/// files if linked together are intended to be equivalent to the single output
/// file that would have been code generated from M.
///
/// \returns M if OSs.size() == 1, otherwise returns std::unique_ptr<Module>().
std::unique_ptr<Module>
splitCodeGen(std::unique_ptr<Module> M, ArrayRef<raw_pwrite_stream *> OSs,
- StringRef CPU, StringRef Features, const TargetOptions &Options,
- Reloc::Model RM = Reloc::Default,
- CodeModel::Model CM = CodeModel::Default,
- CodeGenOpt::Level OL = CodeGenOpt::Default,
- TargetMachine::CodeGenFileType FT = TargetMachine::CGFT_ObjectFile);
+ ArrayRef<llvm::raw_pwrite_stream *> BCOSs,
+ const std::function<std::unique_ptr<TargetMachine>()> &TMFactory,
+ TargetMachine::CodeGenFileType FT = TargetMachine::CGFT_ObjectFile,
+ bool PreserveLocals = false);
} // namespace llvm
OpenPOWER on IntegriCloud
@@ -14,29 +14,34 @@
class TargetOptions;
class raw_pwrite_stream;
-/// Split M into OSs.size() partitions, and generate code for each. Writes
-/// OSs.size() output files to the output streams in OSs. The resulting output
-/// files if linked together are intended to be equivalent to the single output
-/// file that would have been code generated from M.
+/// Split M into OSs.size() partitions, and generate code for each. Takes a
+/// factory function for the TargetMachine TMFactory. Writes OSs.size() output
+/// files to the output streams in OSs. The resulting output files if linked
+/// together are intended to be equivalent to the single output file that would
+/// have been code generated from M.
+///
+/// Writes bitcode for individual partitions into output streams in BCOSs, if
+/// BCOSs is not empty.
///
/// \returns M if OSs.size() == 1, otherwise returns std::unique_ptr<Module>().